@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2017	PgPool Global Development Group
+ * Copyright (c) 2003-2018	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -42,6 +42,7 @@
 
 #include "version.h"
 #include "auth/pool_passwd.h"
+#include "auth/pool_hba.h"
 #include "query_cache/pool_memqcache.h"
 #include "watchdog/wd_utils.h"
 #include "pool_config_variables.h"
@@ -263,11 +264,12 @@ int main(int argc, char **argv)
 		{
 			if (kill(pid, 0) == 0)
 			{
-				fprintf(stderr, "ERROR: pid file found. is another pgpool(%d) is running?\n", pid);
-				exit(EXIT_FAILURE);
+				ereport(FATAL,
+					(errmsg("pid file found. is another pgpool(%d) is running?\n", pid)));
 			}
 			else
-				fprintf(stderr, "NOTICE: pid file found but it seems bogus. Trying to start pgpool anyway...\n");
+				ereport(NOTICE,
+					(errmsg("pid file found but it seems bogus. Trying to start pgpool anyway...\n")));
 		}
 	}
 	/*
@@ -490,6 +492,8 @@ static char *get_pid_file_path(void)
 		ereport(DEBUG1,
 				(errmsg("pid file location is \"%s\"",
 						new)));
+
+		pfree(conf_file_copy);
 	}
 	else
 	{
@@ -560,7 +564,7 @@ static void write_pid_file(void)
 						pool_config->pid_file_name)));
 	}
 
-	fd = open(pid_file, O_CREAT | O_TRUNC | O_WRONLY, S_IRUSR | S_IWUSR);
+	fd = open(pid_file, O_CREAT|O_WRONLY, S_IRUSR|S_IWUSR);
 	if (fd == -1)
 	{
 		ereport(FATAL,
