@@ -107,6 +107,12 @@ POOL_CONFIG* get_pool_config_from_json(char* json_data, int data_len)
 	if (json_get_int_value_for_key(root, "master_slave_sub_mode", (int*)&config->master_slave_sub_mode))
 		goto ERROR_EXIT;
 
+	if (json_get_bool_value_for_key(root, "failover_when_quorum_exists", &config->failover_when_quorum_exists))
+		goto ERROR_EXIT;
+	if (json_get_bool_value_for_key(root, "failover_require_consensus", &config->failover_require_consensus))
+		goto ERROR_EXIT;
+	if (json_get_bool_value_for_key(root, "allow_multiple_failover_requests_from_node", &config->allow_multiple_failover_requests_from_node))
+		goto ERROR_EXIT;
 
 	/* backend_desc array */
 	value = json_get_value_for_key(root,"backend_desc");
@@ -196,6 +202,10 @@ char* get_pool_config_json(void)
 	jw_put_int(jNode, "wd_priority", pool_config->wd_priority);
 	jw_put_int(jNode, "master_slave_sub_mode", pool_config->master_slave_sub_mode);
 
+	jw_put_bool(jNode, "failover_when_quorum_exists", pool_config->failover_when_quorum_exists);
+	jw_put_bool(jNode, "failover_require_consensus", pool_config->failover_require_consensus);
+	jw_put_bool(jNode, "allow_multiple_failover_requests_from_node", pool_config->allow_multiple_failover_requests_from_node);
+
 	/* Array of backends */
 	jw_start_array(jNode, "backend_desc");
 	for (i=0; i < pool_config->backend_desc->num_backends; i++)
@@ -225,7 +235,7 @@ char* get_pool_config_json(void)
 	return json_str;
 }
 
-/* The function returns the simple JSON string that contains
+/* The function returs the simple JSON string that contains
  * only one KEY,VALUE along with the authkey key value if provided
  */
 char* get_simple_request_json(char *key, char* value, unsigned int sharedKey, char* authKey)
@@ -298,6 +308,13 @@ char* get_backend_node_status_json(WatchdogNode* wdNode)
 	for (i=0;i< pool_config->backend_desc->num_backends;i++)
 	{
 		BACKEND_STATUS backend_status = pool_config->backend_desc->backend_info[i].backend_status;
+		if (backend_status == CON_DOWN && pool_config->backend_desc->backend_info[i].quarantine)
+		{
+			/* since quarantine nodes are not cluster wide
+			 * so send CON_WATI status for quarantine nodes
+			 */
+			backend_status = CON_CONNECT_WAIT;
+		}
 		jw_put_int_value(jNode, backend_status);
 	}
 	/* put the primary node id */
@@ -401,10 +418,6 @@ char* get_watchdog_node_info_json(WatchdogNode* wdNode, char* authkey)
 
 	JsonNode* jNode = jw_create_with_object(true);
 
-	jw_put_string(jNode, "PGPOOL_VERSION", VERSION);
-	jw_put_string(jNode, "DATA_VERSION_MAJOR", WD_MESSAGE_DATA_VERSION_MAJOR);
-	jw_put_string(jNode, "DATA_VERSION_MINOR", WD_MESSAGE_DATA_VERSION_MINOR);
-
 	jw_put_int(jNode, "State", wdNode->state);
 	jw_put_int(jNode, "WdPort", wdNode->wd_port);
 	jw_put_int(jNode, "PgpoolPort", wdNode->pgpool_port);
@@ -503,24 +516,6 @@ WatchdogNode* get_watchdog_node_from_json(char* json_data, int data_len, char**
 		goto ERROR_EXIT;
 	strncpy(wdNode->delegate_ip, ptr, sizeof(wdNode->delegate_ip) -1);
 
-	ptr = json_get_string_value_for_key(root, "DATA_VERSION_MAJOR");
-	if (ptr == NULL)
-		wdNode->wd_data_major_version = 1;
-	else
-		wdNode->wd_data_major_version = atoi(ptr);
-
-	ptr = json_get_string_value_for_key(root, "DATA_VERSION_MINOR");
-	if (ptr == NULL)
-		wdNode->wd_data_minor_version = 0;
-	else
-		wdNode->wd_data_minor_version = atoi(ptr);
-
-	ptr = json_get_string_value_for_key(root, "PGPOOL_VERSION");
-	if (ptr != NULL)
-		strncpy(wdNode->pgp_version, ptr, sizeof(wdNode->pgp_version) - 1);
-	else
-		wdNode->pgp_version[0] = '0';
-
 	if (authkey)
 	{
 		ptr = json_get_string_value_for_key(root, "authkey");
@@ -529,7 +524,6 @@ WatchdogNode* get_watchdog_node_from_json(char* json_data, int data_len, char**
 		else
 			*authkey = NULL;
 	}
-
 	return wdNode;
 
 	ERROR_EXIT:
@@ -713,7 +707,7 @@ WDNodeInfo* get_WDNodeInfo_from_wd_node_json(json_value* source)
 	
 }
 
-char* get_wd_node_function_json(char* func_name, int *node_id_set, int count, unsigned int sharedKey, char* authKey)
+char* get_wd_node_function_json(char* func_name, int *node_id_set, int count, unsigned char flags, unsigned int sharedKey, char* authKey)
 {
 	char* json_str;
 	int  i;
@@ -725,6 +719,7 @@ char* get_wd_node_function_json(char* func_name, int *node_id_set, int count, un
 		jw_put_string(jNode, WD_IPC_AUTH_KEY, authKey); /*  put the auth key*/
 
 	jw_put_string(jNode, "Function", func_name);
+	jw_put_int(jNode, "Flags", (int)flags);
 	jw_put_int(jNode, "NodeCount", count);
 	if (count > 0)
 	{
@@ -740,7 +735,7 @@ char* get_wd_node_function_json(char* func_name, int *node_id_set, int count, un
 	return json_str;
 }
 
-bool parse_wd_node_function_json(char* json_data, int data_len, char** func_name, int **node_id_set, int *count)
+bool parse_wd_node_function_json(char* json_data, int data_len, char** func_name, int **node_id_set, int *count, unsigned char *flags)
 {
 	json_value *root, *value;
 	char* ptr;
@@ -773,6 +768,12 @@ bool parse_wd_node_function_json(char* json_data, int data_len, char** func_name
 	}
 	*func_name = pstrdup(ptr);
 	/* If it is a node function ?*/
+	if (json_get_int_value_for_key(root, "Flags", flags))
+	{
+		/*node count not found, But we don't care much about this*/
+		*flags = 0;
+		/* it may be from the old version */
+	}
 	if (json_get_int_value_for_key(root, "NodeCount", &node_count))
 	{
 		/*node count not found, But we don't care much about this*/
